'use strict';

const Protocol = require('azure-iot-device-mqtt').Mqtt;
const Client = require('azure-iot-device').Client;
const methods = require('./direct-methods');
const FirmwareUpdater = require('../az-firmware-updater');

const connString = process.argv[2] || process.env.connectionString;

// Create IoT Hub client
const client = Client.fromConnectionString(connString, Protocol);

const connect = function (err) {
    if (err) {
        console.log(`client error: ${err}`);
    } else {
        console.log('client connected.');

        const options = {
            applyImage: function (imageName) {
                return new Promise(function (fulfill, reject) {
                    setTimeout(function () {
                        console.log(`Applied. ${imageName}`);
                        fulfill();
                    }, 4000);
                });
            },
            cleanup: true
        }

        const firmwareUpdater = new FirmwareUpdater(client, options);
        client.onDeviceMethod('firmwareUpdate', methods.initiateUpdate(firmwareUpdater));

        // handle disconnect and errors.
        client.on('error', function (err) {
            console.log(`client error: ${err}`);
        });

        client.on('disconnect', function () {
            console.log('disconnected');
            client.removeAllListeners();
            client.open(connect);
        });
    }
}

client.open(connect);